load_google_auth

Function load_google_auth 

pub fn load_google_auth(dir: &Path) -> Result<GoogleAuthConfig>
Load optional google-auth.yaml from <dir>/plugins/google-auth.yaml. Returns an empty config when the file is absent so the caller does not have to branch on None.